searchData={"items":[{"type":"module","title":"MDEx","doc":"An extensible Markdown parser and formatter for Elixir. Compliant with CommonMark and supports GitHub, GitLab, and Discord features.","ref":"MDEx.html"},{"type":"module","title":"Features - MDEx","doc":"Compliant with [CommonMark](https://spec.commonmark.org) and [GitHub Flavored Markdown](https://github.github.com/gfm) specifications with extra [extensions](https://docs.rs/comrak/latest/comrak/struct.ExtensionOptions.html)\nas Wiki Links, Discord Markdown tags, and emoji. Also supports syntax highlighting out-of-the-box using the [Autumn](https://github.com/leandrocp/autumn) library.\n\nUnder the hood it's calling the [comrak](https://crates.io/crates/comrak) APIs to process Markdown,\na fast Rust crate that ports the cmark fork maintained by GitHub, a widely and well adopted Markdown implementation.\n\nThe AST structure is based on [Floki](https://hex.pm/packages/floki) so a similar API to manipulate HTML can be used to manipulate Markdown documents.\nCheck out some examples at [mdex/examples/](https://github.com/leandrocp/mdex/tree/main/examples)","ref":"MDEx.html#module-features"},{"type":"module","title":"Installation - MDEx","doc":"Add `:mdex` dependency:\n\n```elixir\ndef deps do\n  [\n    {:mdex, \"~> 0.2\"}\n  ]\nend\n```","ref":"MDEx.html#module-installation"},{"type":"module","title":"Usage - MDEx","doc":"```elixir\nMix.install([{:mdex, \"~> 0.2\"}])\n```\n\n```elixir\niex> MDEx.to_html!(\"# Hello\")\n\" Hello \"\n```\n\n```elixir\niex> MDEx.to_html!(\"# Hello :smile:\", extension: [shortcodes: true])\n\" Hello 😄 \"\n```","ref":"MDEx.html#module-usage"},{"type":"module","title":"Sigils - MDEx","doc":"Convert and generate AST, Markdown (CommonMark), HTML, and XML formats.\n\nFirst, import the sigils:\n\n```elixir\niex> import MDEx.Sigil\n```\n\n```elixir\niex> import MDEx.Sigil\niex> ~M|# Hello from `~M` sigil|\n%MDEx.Document{\n  nodes: [\n    %MDEx.Heading{\n      nodes: [\n        %MDEx.Text{literal: \"Hello from \"},\n        %MDEx.Code{num_backticks: 1, literal: \"~M\"},\n        %MDEx.Text{literal: \" sigil\"}\n      ],\n      level: 1,\n      setext: false\n    }\n  ]\n}\n```\n\n```elixir\niex> import MDEx.Sigil\niex> ~M|`~M` also converts to HTML format|HTML\n\"  ~M  also converts to HTML format \"\n```\n\n```elixir\niex> import MDEx.Sigil\niex> ~M|and to XML as well|XML\n\"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n<!DOCTYPE document SYSTEM \\\"CommonMark.dtd\\\">\\n \\n   \\n     and to XML as well \\n   \\n \\n\"\n```\n\nUse [~m](https://hexdocs.pm/mdex/MDEx.Sigil.html#sigil_m/2) to interpolate variables:\n\n```elixir\niex> import MDEx.Sigil\niex> lang = :elixir\niex> ~m|`lang = #{inspect(lang)}`|\n%MDEx.Document{nodes: [%MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"lang = :elixir\"}]}]}\n```\n\nSee more info at https://hexdocs.pm/mdex/MDEx.Sigil.html","ref":"MDEx.html#module-sigils"},{"type":"module","title":"Safety - MDEx","doc":"For security reasons, every piece of raw HTML is omitted from the output by default:\n\n```elixir\niex> MDEx.to_html!(\" Hello \")\n\"<!-- raw HTML omitted -->\"\n```\n\nThat's not very useful for most cases, but you can render raw HTML and escape it instead:\n\n```elixir\niex> MDEx.to_html!(\" Hello \", render: [escape: true])\n\"&lt;h1&gt;Hello&lt;/h1&gt;\"\n```\n\nIf the input is provided by external sources, it might be a good idea to sanitize it instead for extra security:\n\n```elixir\niex> MDEx.to_html!(\" Elixir \", render: [unsafe_: true], features: [sanitize: true])\n\"  Elixir  \"\n```\n\nNote that you must pass the `unsafe_: true` option to first generate the raw HTML in order to sanitize it.\n\nAll sanitization rules are defined in the [ammonia docs](https://docs.rs/ammonia/latest/ammonia/fn.clean.html).\nFor example, the link in the example below was marked as `noopener noreferrer` to prevent attacks.\n\nIf those rules are too strict and you really trust the input, or you really need to render raw HTML,\nthen you can just render it directly without escaping nor sanitizing:\n\n```elixir\niex> MDEx.to_html!(\" alert('hello') \", render: [unsafe_: true])\n\" alert('hello') \"\n```","ref":"MDEx.html#module-safety"},{"type":"module","title":"Parsing - MDEx","doc":"Converts Markdown to an AST data structure that can be inspected and manipulated to change the content of the document programmatically.\n\nThe data structure format is inspired on [Floki](https://github.com/philss/floki) (with `:attributes_as_maps = true`) so we can keep similar APIs and keep the same mental model when\nworking with these documents, either Markdown or HTML, where each node is represented as a struct holding the node name as the struct name and its attributes and children, for eg:\n\n```elixir\n%MDEx.Heading{\n  level: 1\n  nodes: [...],\n}\n```\n\nThe parent node that represents the root of the document is the [MDEx.Document](https://hexdocs.pm/mdex/MDEx.Document.html) struct,\nwhere you can find more more information about the AST and what operations are available.\n\nThe complete list of nodes is listed in the [documentation](https://hexdocs.pm/mdex/), section `Document Nodes`.","ref":"MDEx.html#module-parsing"},{"type":"module","title":"Formatting - MDEx","doc":"Formatting is the process of converting from one format to another, for example from AST or Markdown to HTML.\nFormatting to XML and to Markdown is also supported.\n\nYou can use [MDEx.parse_document/2](https://hexdocs.pm/mdex/MDEx.html#parse_document/2) to generate an AST or any of the `to_*` functions\nto convert to Markdown (CommonMark), HTML, or XML.","ref":"MDEx.html#module-formatting"},{"type":"module","title":"Options - MDEx","doc":"Use options to change the behavior and the generated output.\n\nAll the [comrak Options](https://docs.rs/comrak/latest/comrak/struct.Options.html) are available as keyword lists,\nand an additional `:features` option to extend it further.\n\n_The full documentation and list of all options with description and examples can be found on the links below:_\n\n* `:extension` - https://docs.rs/comrak/latest/comrak/struct.ExtensionOptions.html\n* `:parse` - https://docs.rs/comrak/latest/comrak/struct.ParseOptions.html\n* `:render` - https://docs.rs/comrak/latest/comrak/struct.RenderOptions.html\n* `:features` - see the available options below","ref":"MDEx.html#module-options"},{"type":"module","title":"Features Options - MDEx","doc":"* `:sanitize` (defaults to `false`) - sanitize output using [ammonia](https://crates.io/crates/ammonia). See the [Safety](#module-safety) section for more info.\n* `:syntax_highlight_theme` (defaults to `\"onedark\"`) - syntax highlight code fences using [autumn themes](https://github.com/leandrocp/autumn/tree/main/priv/themes),\nyou should pass the filename without special chars and without extension, for example you should pass `syntax_highlight_theme: \"adwaita_dark\"` to use the [Adwaita Dark](https://github.com/leandrocp/autumn/blob/main/priv/themes/adwaita-dark.toml) theme\n* `:syntax_highlight_inline_style` (defaults to `true`) - embed styles in the output for each generated token. You'll need to [serve CSS themes](https://github.com/leandrocp/autumn?tab=readme-ov-file#linked) if inline styles are disabled to properly highlight code\n\nSee some examples below on how to use the provided options:","ref":"MDEx.html#module-features-options"},{"type":"module","title":"GitHub Flavored Markdown with [emojis](https://www.webfx.com/tools/emoji-cheat-sheet/) - MDEx","doc":"```elixir\nMDEx.to_html!(~S\"\"\"\n# GitHub Flavored Markdown :rocket:\n\n- [x] Task A\n- [x] Task B\n- [ ] Task C\n\n| Feature | Status |\n| ------- | ------ |\n| Fast | :white_check_mark: |\n| GFM  | :white_check_mark: |\n\nCheck out the spec at https://github.github.com/gfm/\n\"\"\",\nextension: [\n  strikethrough: true,\n  tagfilter: true,\n  table: true,\n  autolink: true,\n  tasklist: true,\n  footnotes: true,\n  shortcodes: true,\n],\nparse: [\n  smart: true,\n  relaxed_tasklist_matching: true,\n  relaxed_autolinks: true\n],\nrender: [\n  github_pre_lang: true,\n  unsafe_: true,\n],\nfeatures: [\n  sanitize: true\n]) |> IO.puts()\n\"\"\"\n GitHub Flavored Markdown 🚀 \n \n     Task A \n     Task B \n     Task C \n \n \n   \n     \n       Feature \n       Status \n     \n   \n   \n     \n       Fast \n       ✅ \n     \n     \n       GFM \n       ✅ \n     \n   \n \n Check out the spec at  https://github.github.com/gfm/  \n\"\"\"\n```","ref":"MDEx.html#module-github-flavored-markdown-with-emojis-https-www-webfx-com-tools-emoji-cheat-sheet"},{"type":"module","title":"Code Syntax Highlighting - MDEx","doc":"````elixir\nMDEx.to_html!(~S\"\"\"\n```elixir\nString.upcase(\"elixir\")\n```\n\"\"\",\nfeatures: [syntax_highlight_theme: \"catppuccin_latte\"]\n) |> IO.puts()\n\"\"\"\n \n   \n     String  .  upcase  (  &quot;elixir&quot;  ) \n   \n \n\"\"\"\n````","ref":"MDEx.html#module-code-syntax-highlighting"},{"type":"module","title":"Pre-compilation - MDEx","doc":"Pre-compiled binaries are available for the following targets, so you don't need to have Rust installed to compile and use this library:\n\n- `aarch64-apple-darwin`\n- `aarch64-unknown-linux-gnu`\n- `aarch64-unknown-linux-musl`\n- `arm-unknown-linux-gnueabihf`\n- `riscv64gc-unknown-linux-gnu`\n- `x86_64-apple-darwin`\n- `x86_64-pc-windows-gnu`\n- `x86_64-pc-windows-msvc`\n- `x86_64-unknown-freebsd`\n- `x86_64-unknown-linux-gnu`\n- `x86_64-unknown-linux-musl`\n\nBut in case you need or want to compile it yourself, you can do the following:\n\n```sh\nexport MDEX_BUILD=1\nmix deps.get\nmix compile\n```","ref":"MDEx.html#module-pre-compilation"},{"type":"module","title":"Legacy CPUs - MDEx","doc":"Modern CPU features are enabled by default but if your environment has an older CPU,\nyou can use legacy artifacts by adding the following configuration to your `config.exs`:\n\n\n```elixir\nconfig :mdex, use_legacy_artifacts: true\n```","ref":"MDEx.html#module-legacy-cpus"},{"type":"module","title":"Demo and Samples - MDEx","doc":"A [livebook](https://github.com/leandrocp/mdex/blob/main/playground.livemd) and a [script](https://github.com/leandrocp/mdex/blob/main/playground.exs) are available to play with and experiment with this library.","ref":"MDEx.html#module-demo-and-samples"},{"type":"module","title":"Used By - MDEx","doc":"- [BeaconCMS](https://github.com/BeaconCMS/beacon)\n- [Tableau](https://github.com/elixir-tools/tableau)\n- [Bonfire](https://github.com/bonfire-networks/bonfire-app)\n- [00](https://github.com/technomancy-dev/00)\n- [Plural Console](https://github.com/pluralsh/console)\n- And [more...](https://github.com/search?q=lang%3Aelixir+%3Amdex&type=code)\n\n_Are you using MDEx and want to list your project here? Please send a PR!_","ref":"MDEx.html#module-used-by"},{"type":"module","title":"Benchmark - MDEx","doc":"A [simple script](benchmark.exs) is available to compare existing libs:\n\n```\nName              ips        average  deviation         median         99th %\ncmark         22.82 K      0.0438 ms    ±16.24%      0.0429 ms      0.0598 ms\nmdex           3.57 K        0.28 ms     ±9.79%        0.28 ms        0.33 ms\nmd             0.34 K        2.95 ms    ±10.56%        2.90 ms        3.62 ms\nearmark        0.25 K        4.04 ms     ±4.50%        4.00 ms        4.44 ms\n\nComparison:\ncmark         22.82 K\nmdex           3.57 K - 6.39x slower +0.24 ms\nmd             0.34 K - 67.25x slower +2.90 ms\nearmark        0.25 K - 92.19x slower +4.00 ms\n```","ref":"MDEx.html#module-benchmark"},{"type":"module","title":"Motivation - MDEx","doc":"MDEx was born out of the necessity of parsing CommonMark files, to parse hundreds of files quickly, and to be easily extensible by consumers of the library.\n\n* [earmark](https://hex.pm/packages/earmark) is extensible but [can't parse](https://github.com/RobertDober/earmark_parser/issues/126) all kinds of documents and is slow to convert hundreds of markdowns.\n* [md](https://hex.pm/packages/md) is very extensible but the doc says \"If one needs to perfectly parse the common markdown, Md is probably not the correct choice\" and CommonMark was a requirement to parse many existing files.\n* [markdown](https://hex.pm/packages/markdown) is not precompiled and has not received updates in a while.\n* [cmark](https://hex.pm/packages/cmark) is a fast CommonMark parser but it requires compiling the C library, is hard to extend, and was archived on Apr 2024\n\n_Note that MDEx is the only one that syntax highlights out-of-the-box which contributes to make it slower than cmark._\n\nTo finish, a friendly reminder that all libs have their own strengths and trade-offs so use the one that better suit your needs.","ref":"MDEx.html#module-motivation"},{"type":"module","title":"Looking for help with your Elixir project? - MDEx","doc":"At DockYard we are [ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting).\nWe have a unique expertise in Elixir and Phoenix development that is unmatched and we love to [write about Elixir](https://dockyard.com/blog/categories/elixir).\n\nHave a project in mind? [Get in touch](https://dockyard.com/contact/hire-us)!","ref":"MDEx.html#module-looking-for-help-with-your-elixir-project"},{"type":"module","title":"Acknowledgements - MDEx","doc":"* [comrak](https://crates.io/crates/comrak) crate for all the heavy work on parsing Markdown and rendering HTML\n* [Floki](https://hex.pm/packages/floki) for the AST manipulation\n* [Logo](https://www.flaticon.com/free-icons/rpg) created by Freepik - Flaticon\n* [Logo font](https://github.com/quoteunquoteapps/CourierPrime) designed by [Alan Greene](https://github.com/a-dg)","ref":"MDEx.html#module-acknowledgements"},{"type":"function","title":"MDEx.parse_document/2","doc":"Parse a `markdown` string and returns a `MDEx.Document`.","ref":"MDEx.html#parse_document/2"},{"type":"function","title":"Options - MDEx.parse_document/2","doc":"See the [Options](#module-options) section for the available `opts`.","ref":"MDEx.html#parse_document/2-options"},{"type":"function","title":"Examples - MDEx.parse_document/2","doc":"iex> MDEx.parse_document!(\"\"\"\n    ...> # Languages\n    ...>\n    ...> - Elixir\n    ...> - Rust\n    ...> \"\"\")\n    %MDEx.Document{\n      nodes: [\n        %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Languages\"}], level: 1, setext: false},\n        %MDEx.List{\n          nodes: [\n            %MDEx.ListItem{\n              nodes: [%MDEx.Paragraph{nodes: [%MDEx.Text{literal: \"Elixir\"}]}],\n              list_type: :bullet,\n              marker_offset: 0,\n              padding: 2,\n              start: 1,\n              delimiter: :period,\n              bullet_char: \"-\",\n              tight: false\n            },\n            %MDEx.ListItem{\n              nodes: [%MDEx.Paragraph{nodes: [%MDEx.Text{literal: \"Rust\"}]}],\n              list_type: :bullet,\n              marker_offset: 0,\n              padding: 2,\n              start: 1,\n              delimiter: :period,\n              bullet_char: \"-\",\n              tight: false\n            }\n          ],\n          list_type: :bullet,\n          marker_offset: 0,\n          padding: 2,\n          start: 1,\n          delimiter: :period,\n          bullet_char: \"-\",\n          tight: true\n        }\n      ]\n    }\n\n    iex> MDEx.parse_document!(\"Darth Vader is ||Luke's father||\", extension: [spoiler: true])\n    %MDEx.Document{\n        nodes: [\n          %MDEx.Paragraph{\n            nodes: [\n              %MDEx.Text{literal: \"Darth Vader is \"},\n              %MDEx.SpoileredText{nodes: [%MDEx.Text{literal: \"Luke's father\"}]}\n            ]\n          }\n        ]\n      }","ref":"MDEx.html#parse_document/2-examples"},{"type":"function","title":"MDEx.parse_document!/2","doc":"Same as `parse_document/2` but raises if the parsing fails.","ref":"MDEx.html#parse_document!/2"},{"type":"function","title":"MDEx.parse_fragment/2","doc":"Parse a `markdown` string and returns only the node that represents the fragment.\n\nUsually that means filtering out the parent document and paragraphs.\n\nThat's useful to generate fragment nodes and inject them into the document\nwhen you're manipulating it.\n\nUse `parse_document/2` to generate a complete document.\n\n> #### Experimental {: .warning}\n>\n> Consider this function experimental and subject to change.","ref":"MDEx.html#parse_fragment/2"},{"type":"function","title":"Examples - MDEx.parse_fragment/2","doc":"iex> MDEx.parse_fragment(\"# Elixir\")\n    {:ok, %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Elixir\"}], level: 1, setext: false}}\n\n    iex> MDEx.parse_fragment(\" Elixir \")\n    {:ok, %MDEx.HtmlBlock{nodes: [], block_type: 6, literal: \" Elixir \\n\"}}","ref":"MDEx.html#parse_fragment/2-examples"},{"type":"function","title":"MDEx.parse_fragment!/2","doc":"Same as `parse_fragment/2` but raises if the parsing fails.\n\n> #### Experimental {: .warning}\n>\n> Consider this function experimental and subject to change.","ref":"MDEx.html#parse_fragment!/2"},{"type":"function","title":"MDEx.safe_html/2","doc":"Utility function to sanitize and escape HTML.","ref":"MDEx.html#safe_html/2"},{"type":"function","title":"Examples - MDEx.safe_html/2","doc":"iex> MDEx.safe_html(\" console.log('attack') \")\n    \"\"\n\n    iex> MDEx.safe_html(\" {'Example:'}  {:ok, 'MDEx'} \")\n    \"&lt;h1&gt;{&#x27;Example:&#x27;}&lt;&#x2f;h1&gt;&lt;code&gt;&lbrace;:ok, &#x27;MDEx&#x27;&rbrace;&lt;&#x2f;code&gt;\"\n\n    iex> MDEx.safe_html(\" {'Example:'}  {:ok, 'MDEx'} \", escape: [content: false])\n    \" {'Example:'}  &lbrace;:ok, 'MDEx'&rbrace; \"","ref":"MDEx.html#safe_html/2-examples"},{"type":"function","title":"Options - MDEx.safe_html/2","doc":"- `:sanitize` - clean HTML using these rules https://docs.rs/ammonia/latest/ammonia/fn.clean.html. Defaults to `true`.\n  - `:escape` - which entities should be escaped. Defaults to `[:content, :curly_braces_in_code]`.\n      - `:content` - escape common chars like `<`, `>`, `&`, and others in the HTML content;\n      - `:curly_braces_in_code` - escape `{` and `}` only inside ` ` tags, particularly useful for compiling HTML in LiveView;","ref":"MDEx.html#safe_html/2-options"},{"type":"function","title":"MDEx.to_commonmark/1","doc":"Convert an AST to CommonMark using default options.\n\nTo customize the output, use `to_commonmark/2`.","ref":"MDEx.html#to_commonmark/1"},{"type":"function","title":"Example - MDEx.to_commonmark/1","doc":"iex> MDEx.to_commonmark(%MDEx.Document{nodes: [%MDEx.Heading{nodes: [%MDEx.Text{literal: \"Hello\"}], level: 3, setext: false}]})\n    {:ok, \"","ref":"MDEx.html#to_commonmark/1-example"},{"type":"function","title":"Hello\"} - MDEx.to_commonmark/1","doc":"","ref":"MDEx.html#to_commonmark/1-hello"},{"type":"function","title":"MDEx.to_commonmark/2","doc":"Convert an AST to CommonMark with custom options.","ref":"MDEx.html#to_commonmark/2"},{"type":"function","title":"Options - MDEx.to_commonmark/2","doc":"See the [Options](#module-options) section for the available options.","ref":"MDEx.html#to_commonmark/2-options"},{"type":"function","title":"MDEx.to_commonmark!/1","doc":"Same as `to_commonmark/1` but raises `MDEx.DecodeError` if the conversion fails.","ref":"MDEx.html#to_commonmark!/1"},{"type":"function","title":"MDEx.to_commonmark!/2","doc":"Same as `to_commonmark/2` but raises `MDEx.DecodeError` if the conversion fails.","ref":"MDEx.html#to_commonmark!/2"},{"type":"function","title":"MDEx.to_html/1","doc":"Convert Markdown or `MDEx.Document` to HTML using default options.\n\nUse `to_html/2` to pass options and customize the generated HTML.","ref":"MDEx.html#to_html/1"},{"type":"function","title":"Examples - MDEx.to_html/1","doc":"iex> MDEx.to_html(\"# MDEx\")\n    {:ok, \" MDEx \"}\n\n    iex> MDEx.to_html(\"Implemented with:\\n1. Elixir\\n2. Rust\")\n    {:ok, \" Implemented with: \\n \\n Elixir \\n Rust \\n \"}\n\n    iex> MDEx.to_html(%MDEx.Document{nodes: [%MDEx.Heading{nodes: [%MDEx.Text{literal: \"MDEx\"}], level: 3, setext: false}]})\n    {:ok, \" MDEx \"}\n\nFragments of a document are also supported:\n\n    iex> MDEx.to_html(%MDEx.Paragraph{nodes: [%MDEx.Text{literal: \"MDEx\"}]})\n    {:ok, \" MDEx \"}","ref":"MDEx.html#to_html/1-examples"},{"type":"function","title":"MDEx.to_html/2","doc":"Convert Markdown or `MDEx.Document` to HTML using custom options.","ref":"MDEx.html#to_html/2"},{"type":"function","title":"Options - MDEx.to_html/2","doc":"See the [Options](#module-options) section for the available options.","ref":"MDEx.html#to_html/2-options"},{"type":"function","title":"Examples - MDEx.to_html/2","doc":"iex> MDEx.to_html(\"Hello ~world~ there\", extension: [strikethrough: true])\n    {:ok, \" Hello  world  there \"}\n\n    iex> MDEx.to_html(\" visit https://beaconcms.org \", extension: [autolink: true], render: [unsafe_: true])\n    {:ok, \"  visit  https://beaconcms.org   \"}","ref":"MDEx.html#to_html/2-examples"},{"type":"function","title":"MDEx.to_html!/1","doc":"Same as `to_html/1` but raises an error if the conversion fails.","ref":"MDEx.html#to_html!/1"},{"type":"function","title":"MDEx.to_html!/2","doc":"Same as `to_html/2` but raises error if the conversion fails.","ref":"MDEx.html#to_html!/2"},{"type":"function","title":"MDEx.to_xml/1","doc":"Convert Markdown or `MDEx.Document` to XML using default options.\n\nUse `to_xml/2` to pass options and customize the generated XML.","ref":"MDEx.html#to_xml/1"},{"type":"function","title":"Examples - MDEx.to_xml/1","doc":"iex> {:ok, xml} =  MDEx.to_xml(\"# MDEx\")\n    iex> xml\n    \"\"\"\n    <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    <!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n     \n       \n         MDEx \n       \n     \n    \"\"\"\n\n    iex> {:ok, xml} = MDEx.to_xml(\"Implemented with:\\n1. Elixir\\n2. Rust\")\n    iex> xml\n    \"\"\"\n    <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    <!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n     \n       \n         Implemented with: \n       \n       \n         \n           \n             Elixir \n           \n         \n         \n           \n             Rust \n           \n         \n       \n     \n    \"\"\"\n\n    iex> {:ok, xml} = MDEx.to_xml(%MDEx.Document{nodes: [%MDEx.Heading{nodes: [%MDEx.Text{literal: \"MDEx\"}], level: 3, setext: false}]})\n    iex> xml\n    \"\"\"\n    <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    <!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n     \n       \n         MDEx \n       \n     \n    \"\"\"\n\nFragments of a document are also supported:\n\n    iex> {:ok, xml} = MDEx.to_xml(%MDEx.Paragraph{nodes: [%MDEx.Text{literal: \"MDEx\"}]})\n    iex> xml\n    \"\"\"\n    <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    <!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n     \n       \n         MDEx \n       \n     \n    \"\"\"","ref":"MDEx.html#to_xml/1-examples"},{"type":"function","title":"MDEx.to_xml/2","doc":"Convert Markdown or `MDEx.Document` to XML using custom options.","ref":"MDEx.html#to_xml/2"},{"type":"function","title":"Options - MDEx.to_xml/2","doc":"See the [Options](#module-options) section for the available options.","ref":"MDEx.html#to_xml/2-options"},{"type":"function","title":"Examples - MDEx.to_xml/2","doc":"iex> {:ok, xml} = MDEx.to_xml(\"Hello ~world~ there\", extension: [strikethrough: true])\n    iex> xml\n    \"\"\"\n    <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    <!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n     \n       \n         Hello  \n         \n           world \n         \n          there \n       \n     \n    \"\"\"\n\n    iex> {:ok, xml} = MDEx.to_xml(\" visit https://beaconcms.org \", extension: [autolink: true], render: [unsafe_: true])\n    iex> xml\n    \"\"\"\n    <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n    <!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n     \n       \n         &lt;marquee&gt; \n         visit  \n         \n           https://beaconcms.org \n         \n         &lt;/marquee&gt; \n       \n     \n    \"\"\"","ref":"MDEx.html#to_xml/2-examples"},{"type":"function","title":"MDEx.to_xml!/1","doc":"Same as `to_xml/1` but raises an error if the conversion fails.","ref":"MDEx.html#to_xml!/1"},{"type":"function","title":"MDEx.to_xml!/2","doc":"Same as `to_xml/2` but raises error if the conversion fails.","ref":"MDEx.html#to_xml!/2"},{"type":"function","title":"MDEx.traverse_and_update/2","doc":"Traverse and update the Markdown document preserving the tree structure format.","ref":"MDEx.html#traverse_and_update/2"},{"type":"function","title":"Examples - MDEx.traverse_and_update/2","doc":"Traverse an entire Markdown document:\n\n\n    iex> import MDEx.Sigil\n    iex> doc = ~M\"\"\"\n    ...> # Languages\n    ...>\n    ...> `elixir`\n    ...>\n    ...> `rust`\n    ...> \"\"\"\n    iex> MDEx.traverse_and_update(doc, fn\n    ...>   %MDEx.Code{literal: \"elixir\"} = node -> %{node | literal: \"ex\"}\n    ...>   %MDEx.Code{literal: \"rust\"} = node -> %{node | literal: \"rs\"}\n    ...>   node -> node\n    ...> end)\n    %MDEx.Document{\n      nodes: [\n        %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Languages\"}], level: 1, setext: false},\n        %MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"ex\"}]},\n        %MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"rs\"}]}\n      ]\n    }\n\n  Or fragments of a document:\n\n    iex> fragment = MDEx.parse_fragment!(\"Lang: `elixir`\")\n    iex> MDEx.traverse_and_update(fragment, fn\n    ...>   %MDEx.Code{literal: \"elixir\"} = node -> %{node | literal: \"ex\"}\n    ...>   node -> node\n    ...> end)\n    %MDEx.Paragraph{nodes: [%MDEx.Text{literal: \"Lang: \"}, %MDEx.Code{num_backticks: 1, literal: \"ex\"}]}","ref":"MDEx.html#traverse_and_update/2-examples"},{"type":"function","title":"MDEx.traverse_and_update/3","doc":"Traverse and update the Markdown document preserving the tree structure format and keeping an accumulator.","ref":"MDEx.html#traverse_and_update/3"},{"type":"function","title":"Example - MDEx.traverse_and_update/3","doc":"iex> import MDEx.Sigil\n    iex> doc = ~M\"\"\"\n    ...> # Languages\n    ...>\n    ...> `elixir`\n    ...>\n    ...> `rust`\n    ...> \"\"\"\n    iex> MDEx.traverse_and_update(doc, 0, fn\n    ...>   %MDEx.Code{literal: \"elixir\"} = node, acc -> {%{node | literal: \"ex\"}, acc + 1}\n    ...>   %MDEx.Code{literal: \"rust\"} = node, acc -> {%{node | literal: \"rs\"}, acc + 1}\n    ...>   node, acc -> {node, acc}\n    ...> end)\n    {%MDEx.Document{\n      nodes: [\n        %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Languages\"}], level: 1, setext: false},\n        %MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"ex\"}]},\n        %MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"rs\"}]}\n      ]\n    }, 2}\n\nAlso works with fragments.","ref":"MDEx.html#traverse_and_update/3-example"},{"type":"module","title":"MDEx.Alert","doc":"GitHub and GitLab style alerts / admonitions.\n\nSee [GitHub](https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax#alerts)\nand [GitLab](https://docs.gitlab.com/user/markdown/#alerts) docs.","ref":"MDEx.Alert.html"},{"type":"type","title":"MDEx.Alert.t/0","doc":"","ref":"MDEx.Alert.html#t:t/0"},{"type":"module","title":"MDEx.Document","doc":"Tree representation of a CommonMark document.\n\n```elixir\n%MDEx.Document{\n  nodes: [\n    %MDEx.Paragraph{\n      nodes: [\n        %MDEx.Code{num_backticks: 1, literal: \"Elixir\"}\n      ]\n    }\n  ]\n}\n```\n\nEach node may contain attributes and children nodes as in the example above where `MDEx.Document`\ncontains a `MDEx.Paragraph` node which contains a `MDEx.Code` node with the attributes `:num_backticks` and `:literal`.\n\nYou can check out each node's documentation in the `Document Nodes` section, for example `MDEx.HtmlBlock`.\n\nThe wrapping `MDEx.Document` module represents the root of a document and it implements some behaviours and protocols\nto enable operations to fetch, update, and manipulate the document tree.\n\nLet's go through these operations in the examples below.\n\nIn these examples we will be using the [~M](https://hexdocs.pm/mdex/MDEx.Sigil.html#sigil_M/2)\nand [~m](https://hexdocs.pm/mdex/MDEx.Sigil.html#sigil_m/2) to format the content,\nsee their documentation for more info.","ref":"MDEx.Document.html"},{"type":"module","title":"String.Chars - MDEx.Document","doc":"Calling `Kernel.to_string/1` or interpolating the document AST will format it as CommonMark text.\n\n```elixir\niex> to_string(~M[# Hello])\n\"# Hello\"\n```\n\nFragments (nodes without the parent `%Document{}`) are also formatted:\n\n```elixir\niex> to_string(%MDEx.Heading{nodes: [%MDEx.Text{literal: \"Hello\"}], level: 1})\n\"# Hello\"\n```\n\nAnd finally interpolation as well:\n\n```elixir\niex> lang = \"elixir\"\niex> to_string(~m[`#{lang}`])\n\"`elixir`\"\n```","ref":"MDEx.Document.html#module-string-chars"},{"type":"module","title":"Access - MDEx.Document","doc":"The `Access` behaviour gives you the ability to fetch and update nodes using different types of keys.\n\nStarting with a simple Markdown document with a single heading and a text,\nlet's fetch only the text node by matching the `MDEx.Text` node:\n\n```elixir\niex> ~M[# Hello][%MDEx.Text{literal: \"Hello\"}]\n[%MDEx.Text{literal: \"Hello\"}]\n```\n\nThat's essentially the same as:\n\n```elixir\ndoc = %MDEx.Document{nodes: [%MDEx.Heading{nodes: [%MDEx.Text{literal: \"Hello\"}], level: 1, setext: false}]},\n\nEnum.filter(\n  doc,\n  fn node -> node == %MDEx.Text{literal: \"Hello\"} end\n)\n```\n\nThe key can also be modules, atoms, and even functions! For example:\n\n- Fetches all Code nodes, either by `MDEx.Code` module or the `:code` atom representing the Code node\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...> \"\"\"\niex> doc[MDEx.Code]\n[%MDEx.Code{num_backticks: 1, literal: \"elixir\"}, %MDEx.Code{num_backticks: 1, literal: \"rust\"}]\niex> doc[:code]\n[%MDEx.Code{num_backticks: 1, literal: \"elixir\"}, %MDEx.Code{num_backticks: 1, literal: \"rust\"}]\n```\n\n- Dynamically fetch Code nodes where the `:literal` (node content) starts with `\"eli\"` using a function to filter the result\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...> \"\"\"\niex> doc[fn node -> String.starts_with?(Map.get(node, :literal, \"\"), \"eli\") end]\n[%MDEx.Code{num_backticks: 1, literal: \"elixir\"}]\n```\n\nThat's the most flexible option, in the case where struct, modules, or atoms are not enough to match the node you want.\n\nThis protocol also allows us to update nodes that matches a selector.\nIn the example below we'll capitalize the content of all `MDEx.Code` nodes:\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...>\n...> Continue...\n...> \"\"\"\niex> update_in(doc, [:document, Access.key!(:nodes), Access.all(), :code, Access.key!(:literal)], fn literal ->\n...>   String.upcase(literal)\n...> end)\n%MDEx.Document{\n  nodes: [\n    %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Languages\"}], level: 1, setext: false},\n    %MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"ELIXIR\"}]},\n    %MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"RUST\"}]},\n    %MDEx.Paragraph{nodes: [%MDEx.Text{literal: \"Continue…\"}]}\n  ]\n}\n```","ref":"MDEx.Document.html#module-access"},{"type":"module","title":"Enumerable - MDEx.Document","doc":"Probably the most used protocol in Elixir, it allows us to call `Enum` functions to manipulate the document. Let's see some examples:\n\n* Count the nodes in a document:\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...> \"\"\"\niex> Enum.count(doc)\n7\n```\n\n* Count how many nodes have the `:literal` attribute:\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...> \"\"\"\niex> Enum.reduce(doc, 0, fn\n...>   %{literal: _literal}, acc -> acc + 1\n...>\n...>   _node, acc -> acc\n...> end)\n3\n```\n\n* Returns true if node is member of the document:\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...> \"\"\"\niex> Enum.member?(doc, %MDEx.Code{literal: \"elixir\", num_backticks: 1})\ntrue\n```\n\n* Map each node:\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Languages\n...>\n...> `elixir`\n...>\n...> `rust`\n...> \"\"\"\niex> Enum.map(doc, fn %node{} -> inspect(node) end)\n[\"MDEx.Document\", \"MDEx.Heading\", \"MDEx.Text\", \"MDEx.Paragraph\", \"MDEx.Code\", \"MDEx.Paragraph\", \"MDEx.Code\"]\n```","ref":"MDEx.Document.html#module-enumerable"},{"type":"module","title":"Traverse and Update - MDEx.Document","doc":"You can also use the low-level `MDEx.traverse_and_update/2` and `MDEx.traverse_and_update/3` APIs\nto traverse each node of the AST and either update the nodes or do some calculation with an accumulator.","ref":"MDEx.Document.html#module-traverse-and-update"},{"type":"module","title":"Examples - MDEx.Document","doc":"#### Update all code block nodes filtees by the `selector` function\n\n_Add line \"// Modified\" in Rust block codes_:\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Code Examples\n...>\n...> ```elixir\n...> def hello do\n...>   :world\n...> end\n...> ```\n...>\n...> ```rust\n...> fn main() {\n...>   println!(\"Hello\");\n...> }\n...> ```\n...> \"\"\"\niex> selector = fn\n...>   %MDEx.CodeBlock{info: \"rust\"} -> true\n...>   _ -> false\n...> end\niex> update_in(doc, [:document, Access.key!(:nodes), Access.all(), selector], fn node ->\n...>   %{node | literal: \"// Modified\\n\" <> node.literal}\n...> end)\n%MDEx.Document{\n  nodes: [\n    %MDEx.Heading{\n      nodes: [%MDEx.Text{literal: \"Code Examples\"}],\n      level: 1,\n      setext: false\n    },\n    %MDEx.CodeBlock{\n      info: \"elixir\",\n      literal: \"def hello do\\n  :world\\nend\\n\"\n    },\n    %MDEx.CodeBlock{\n      info: \"rust\",\n      literal: \"// Modified\\nfn main() {\\n  println!(\\\"Hello\\\");\\n}\\n\"\n    }\n  ]\n}\n```\n\n#### Collect headings by level\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Main Title\n...>\n...>","ref":"MDEx.Document.html#module-examples"},{"type":"module","title":"Section 1 - MDEx.Document","doc":"...>\n...>","ref":"MDEx.Document.html#module-section-1"},{"type":"module","title":"Subsection - MDEx.Document","doc":"...>\n...>","ref":"MDEx.Document.html#module-subsection"},{"type":"module","title":"Section 2 - MDEx.Document","doc":"...> \"\"\"\niex> Enum.reduce(doc, %{}, fn\n...>   %MDEx.Heading{level: level, nodes: [%MDEx.Text{literal: text}]}, acc ->\n...>     Map.update(acc, level, [text], &[text | &1])\n...>   _node, acc -> acc\n...> end)\n%{\n  1 => [\"Main Title\"],\n  2 => [\"Section 2\", \"Section 1\"],\n  3 => [\"Subsection\"]\n}\n```\n\n#### Extract and transform task list items\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Todo List\n...>\n...> - [ ] Buy groceries\n...> - [x] Call mom\n...> - [ ] Read book\n...> \"\"\"\niex> Enum.map(doc, fn\n...>   %MDEx.TaskItem{checked: checked, nodes: [%MDEx.Paragraph{nodes: [%MDEx.Text{literal: text}]}]} ->\n...>     {checked, text}\n...>   _ -> nil\n...> end)\n...> |> Enum.reject(&is_nil/1)\n[\n  {false, \"Buy groceries\"},\n  {true, \"Call mom\"},\n  {false, \"Read book\"}\n]\n```\n\n#### Bump all heading levels, except level 6\n\n```elixir\niex> doc = ~M\"\"\"\n...> # Main Title\n...>\n...>","ref":"MDEx.Document.html#module-section-2"},{"type":"module","title":"Subtitle - MDEx.Document","doc":"...>\n...> ###### Notes\n...> \"\"\"\niex> selector = fn\n...>   %MDEx.Heading{level: level} when level < 6 -> true\n...>   _ -> false\n...> end\niex> update_in(doc, [:document, Access.key!(:nodes), Access.all(), selector], fn node ->\n...>   %{node | level: node.level + 1}\n...> end)\n%MDEx.Document{\n  nodes: [\n    %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Main Title\"}], level: 2, setext: false},\n    %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Subtitle\"}], level: 3, setext: false},\n    %MDEx.Heading{nodes: [%MDEx.Text{literal: \"Notes\"}], level: 6, setext: false}\n  ]\n}\n```","ref":"MDEx.Document.html#module-subtitle"},{"type":"function","title":"MDEx.Document.fetch/2","doc":"Callback implementation for `Access.fetch/2`.\n\nSee the [Access](#module-access) section for examples.","ref":"MDEx.Document.html#fetch/2"},{"type":"function","title":"MDEx.Document.get_and_update/3","doc":"Callback implementation for `Access.get_and_update/3`.\n\nSee the [Access](#module-access) section for examples.","ref":"MDEx.Document.html#get_and_update/3"},{"type":"type","title":"MDEx.Document.md_node/0","doc":"Fragment of a CommonMark document, a single node.","ref":"MDEx.Document.html#t:md_node/0"},{"type":"function","title":"MDEx.Document.pop/3","doc":"Callback implementation for `Access.fetch/2`.\n\nSee the [Access](#module-access) section for examples.","ref":"MDEx.Document.html#pop/3"},{"type":"type","title":"MDEx.Document.selector/0","doc":"Selector to match a node in a document.","ref":"MDEx.Document.html#t:selector/0"},{"type":"type","title":"MDEx.Document.t/0","doc":"Tree representation of a CommonMark document.","ref":"MDEx.Document.html#t:t/0"},{"type":"module","title":"MDEx.Sigil","doc":"Sigils for parsing and formatting Markdown between different formats.","ref":"MDEx.Sigil.html"},{"type":"module","title":"Modifiers - MDEx.Sigil","doc":"* `HTML` - converts Markdown or `MDEx.Document` to HTML, equivalent to calling `MDEx.to_html!/2`\n  * `XML` - converts Markdown or `MDEx.Document` to XML, equivalent to calling `MDEx.to_xml!/2`\n  * `MD` - converts `MDEx.Document` to Markdown, equivalent to calling `MDEx.to_commonmark!/2`\n\nWithout a modifier it converts Markdown to `MDEx.Document` (the default output of `~m` and `~M`), equivalent to calling `MDEx.parse_document!/2`.\n\nNote that you should `import MDEx.Sigil` to use the `~m` or `~M` sigil.","ref":"MDEx.Sigil.html#module-modifiers"},{"type":"module","title":"Options - MDEx.Sigil","doc":"In order to support the most common scenarios, all sigils use the following options by default:\n\n```elixir\n[\n  extension: [\n    strikethrough: true,\n    table: true,\n    autolink: true,\n    tasklist: true,\n    superscript: true,\n    footnotes: true,\n    description_lists: true,\n    multiline_block_quotes: true,\n    alerts: true,\n    math_dollars: true,\n    math_code: true,\n    shortcodes: true,\n    underline: true,\n    spoiler: true\n  ],\n  parse: [smart: true, relaxed_tasklist_matching: true, relaxed_autolinks: true],\n  render: [_unsafe: true]\n]\n```\n\nIf you need a different set of options, you can call the regular functions in `MDEx` to pass the options you need.","ref":"MDEx.Sigil.html#module-options"},{"type":"macro","title":"MDEx.Sigil.sigil_M/2","doc":"The `~M` sigil converts to `MDEx.Document`, CommonMark, HTML, or XML without interpolation.","ref":"MDEx.Sigil.html#sigil_M/2"},{"type":"macro","title":"Examples - MDEx.Sigil.sigil_M/2","doc":"","ref":"MDEx.Sigil.html#sigil_M/2-examples"},{"type":"macro","title":"Markdown to `MDEx.Document` - MDEx.Sigil.sigil_M/2","doc":"```elixir\niex> ~M[`lang = :elixir`]\n%MDEx.Document{nodes: [%MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"lang = :elixir\"}]}]}\n```","ref":"MDEx.Sigil.html#sigil_M/2-markdown-to-mdex-document"},{"type":"macro","title":"Markdown to HTML - MDEx.Sigil.sigil_M/2","doc":"```elixir\niex> ~M[`lang = :elixir`]HTML\n\"  lang = :elixir  \\n\"\n```","ref":"MDEx.Sigil.html#sigil_M/2-markdown-to-html"},{"type":"macro","title":"Markdown to XML - MDEx.Sigil.sigil_M/2","doc":"```elixir\niex> ~M[`lang = :elixir`]XML\n\"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE document SYSTEM \"CommonMark.dtd\">\n \n   \n     lang = :elixir \n   \n \n\"\n```\n\n### `MDEx.Document` to Markdown\n\n```elixir\niex> ~M|%MDEx.Document{nodes: [%MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"lang = :elixir\"}]}]}|MD\n\"`lang = :elixir`\"\n```\n\nOther modifiers also convert from a document to the desired format.","ref":"MDEx.Sigil.html#sigil_M/2-markdown-to-xml"},{"type":"macro","title":"MDEx.Sigil.sigil_m/2","doc":"The `~m` sigil converts to `MDEx.Document`, CommonMark, HTML, or XML with interpolation.","ref":"MDEx.Sigil.html#sigil_m/2"},{"type":"macro","title":"Examples - MDEx.Sigil.sigil_m/2","doc":"","ref":"MDEx.Sigil.html#sigil_m/2-examples"},{"type":"macro","title":"Markdown to `MDEx.Document` - MDEx.Sigil.sigil_m/2","doc":"iex> lang = :elixir\n    iex> ~m[`lang = #{inspect(lang)}`]\n    %MDEx.Document{nodes: [%MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"lang = :elixir\"}]}]}\n\n### `MDEx.Document` to Markdown\n\n    iex> lang = :elixir\n    iex> ~m|%MDEx.Document{nodes: [%MDEx.Paragraph{nodes: [%MDEx.Code{num_backticks: 1, literal: \"lang = #{inspect(lang)}\"}]}]}|\n    \"`lang = :elixir`\"\n\nOther modifiers also accept interpolation.","ref":"MDEx.Sigil.html#sigil_m/2-markdown-to-mdex-document"},{"type":"module","title":"MDEx.BlockQuote","doc":"A block quote marker.\n\nSpec: https://github.github.com/gfm/#block-quotes","ref":"MDEx.BlockQuote.html"},{"type":"type","title":"MDEx.BlockQuote.t/0","doc":"","ref":"MDEx.BlockQuote.html#t:t/0"},{"type":"module","title":"MDEx.Code","doc":"Inline code span.\n\nSpec: https://github.github.com/gfm/#code-spans","ref":"MDEx.Code.html"},{"type":"type","title":"MDEx.Code.t/0","doc":"","ref":"MDEx.Code.html#t:t/0"},{"type":"module","title":"MDEx.CodeBlock","doc":"A code block, fenced or indented.\n\nSpec: https://github.github.com/gfm/#fenced-code-blocks and https://github.github.com/gfm/#indented-code-blocks","ref":"MDEx.CodeBlock.html"},{"type":"type","title":"MDEx.CodeBlock.t/0","doc":"","ref":"MDEx.CodeBlock.html#t:t/0"},{"type":"module","title":"MDEx.DescriptionDetails","doc":"Description details of a description item.\n\nSee `MDEx.DescriptionList`","ref":"MDEx.DescriptionDetails.html"},{"type":"type","title":"MDEx.DescriptionDetails.t/0","doc":"","ref":"MDEx.DescriptionDetails.html#t:t/0"},{"type":"module","title":"MDEx.DescriptionItem","doc":"A description item of a description list.\n\nSee `MDEx.DescriptionList`","ref":"MDEx.DescriptionItem.html"},{"type":"type","title":"MDEx.DescriptionItem.t/0","doc":"","ref":"MDEx.DescriptionItem.html#t:t/0"},{"type":"module","title":"MDEx.DescriptionList","doc":"A description list.","ref":"MDEx.DescriptionList.html"},{"type":"type","title":"MDEx.DescriptionList.t/0","doc":"","ref":"MDEx.DescriptionList.html#t:t/0"},{"type":"module","title":"MDEx.DescriptionTerm","doc":"A description term of a description item.\n\nSee `MDEx.DescriptionList`","ref":"MDEx.DescriptionTerm.html"},{"type":"type","title":"MDEx.DescriptionTerm.t/0","doc":"","ref":"MDEx.DescriptionTerm.html#t:t/0"},{"type":"module","title":"MDEx.Emph","doc":"Emphasis.\n\nSpec: https://github.github.com/gfm/#emphasis-and-strong-emphasis","ref":"MDEx.Emph.html"},{"type":"type","title":"MDEx.Emph.t/0","doc":"","ref":"MDEx.Emph.html#t:t/0"},{"type":"module","title":"MDEx.Escaped","doc":"An escaped character.\n\nSpec: https://github.github.com/gfm/#backslash-escapes","ref":"MDEx.Escaped.html"},{"type":"type","title":"MDEx.Escaped.t/0","doc":"","ref":"MDEx.Escaped.html#t:t/0"},{"type":"module","title":"MDEx.EscapedTag","doc":"Escaped tag.","ref":"MDEx.EscapedTag.html"},{"type":"type","title":"MDEx.EscapedTag.t/0","doc":"","ref":"MDEx.EscapedTag.html#t:t/0"},{"type":"module","title":"MDEx.FootnoteDefinition","doc":"A footnote definition.","ref":"MDEx.FootnoteDefinition.html"},{"type":"type","title":"MDEx.FootnoteDefinition.t/0","doc":"","ref":"MDEx.FootnoteDefinition.html#t:t/0"},{"type":"module","title":"MDEx.FootnoteReference","doc":"The reference to a footnote.","ref":"MDEx.FootnoteReference.html"},{"type":"type","title":"MDEx.FootnoteReference.t/0","doc":"","ref":"MDEx.FootnoteReference.html#t:t/0"},{"type":"module","title":"MDEx.FrontMatter","doc":"Document metadata.","ref":"MDEx.FrontMatter.html"},{"type":"type","title":"MDEx.FrontMatter.t/0","doc":"","ref":"MDEx.FrontMatter.html#t:t/0"},{"type":"module","title":"MDEx.Heading","doc":"A heading, either ATX or setext.\n\nATX is the most common heading, a line starting with 1-6 `#` characters,\nand setext is represented as one or more lines followed by a heading underline as `===` or `---`.\n\nSpec: https://github.github.com/gfm/#atx-headings and https://github.github.com/gfm/#setext-headings","ref":"MDEx.Heading.html"},{"type":"type","title":"MDEx.Heading.t/0","doc":"","ref":"MDEx.Heading.html#t:t/0"},{"type":"module","title":"MDEx.HtmlBlock","doc":"A HTML block.\n\nSpec: https://github.github.com/gfm/#html-blocks","ref":"MDEx.HtmlBlock.html"},{"type":"type","title":"MDEx.HtmlBlock.t/0","doc":"","ref":"MDEx.HtmlBlock.html#t:t/0"},{"type":"module","title":"MDEx.HtmlInline","doc":"Raw HTML.\n\nSpec: https://github.github.com/gfm/#raw-html","ref":"MDEx.HtmlInline.html"},{"type":"type","title":"MDEx.HtmlInline.t/0","doc":"","ref":"MDEx.HtmlInline.html#t:t/0"},{"type":"module","title":"MDEx.Image","doc":"An image.\n\nSpec: https://github.github.com/gfm/#images","ref":"MDEx.Image.html"},{"type":"type","title":"MDEx.Image.t/0","doc":"","ref":"MDEx.Image.html#t:t/0"},{"type":"module","title":"MDEx.LineBreak","doc":"A hard line break.\n\nSpec: https://github.github.com/gfm/#hard-line-breaks","ref":"MDEx.LineBreak.html"},{"type":"type","title":"MDEx.LineBreak.t/0","doc":"","ref":"MDEx.LineBreak.html#t:t/0"},{"type":"module","title":"MDEx.Link","doc":"Link to a URL.\n\nSpec: https://github.github.com/gfm/#links","ref":"MDEx.Link.html"},{"type":"type","title":"MDEx.Link.t/0","doc":"","ref":"MDEx.Link.html#t:t/0"},{"type":"module","title":"MDEx.List","doc":"A List that contains `MDEx.ListItem`.\n\nSpec: https://github.github.com/gfm/#lists","ref":"MDEx.List.html"},{"type":"type","title":"MDEx.List.t/0","doc":"","ref":"MDEx.List.html#t:t/0"},{"type":"module","title":"MDEx.ListItem","doc":"A List Item of a `MDEx.List`.\n\nSpec: https://github.github.com/gfm/#list-items","ref":"MDEx.ListItem.html"},{"type":"type","title":"MDEx.ListItem.t/0","doc":"","ref":"MDEx.ListItem.html#t:t/0"},{"type":"module","title":"MDEx.Math","doc":"Inline math span.","ref":"MDEx.Math.html"},{"type":"type","title":"MDEx.Math.t/0","doc":"","ref":"MDEx.Math.html#t:t/0"},{"type":"module","title":"MDEx.MultilineBlockQuote","doc":"A multiline block quote.\n\nSpec: https://github.github.com/gfm/#block-quotes","ref":"MDEx.MultilineBlockQuote.html"},{"type":"type","title":"MDEx.MultilineBlockQuote.t/0","doc":"","ref":"MDEx.MultilineBlockQuote.html#t:t/0"},{"type":"module","title":"MDEx.Paragraph","doc":"A paragraph that contains nodes.\n\nSpec: https://github.github.com/gfm/#paragraphs","ref":"MDEx.Paragraph.html"},{"type":"type","title":"MDEx.Paragraph.t/0","doc":"","ref":"MDEx.Paragraph.html#t:t/0"},{"type":"module","title":"MDEx.Raw","doc":"A Raw output node. This will be inserted verbatim into CommonMark and HTML output. It can only be created programmatically, and is never parsed from input.","ref":"MDEx.Raw.html"},{"type":"type","title":"MDEx.Raw.t/0","doc":"","ref":"MDEx.Raw.html#t:t/0"},{"type":"module","title":"MDEx.ShortCode","doc":"Emoji generated from a shortcode.","ref":"MDEx.ShortCode.html"},{"type":"type","title":"MDEx.ShortCode.t/0","doc":"","ref":"MDEx.ShortCode.html#t:t/0"},{"type":"module","title":"MDEx.SoftBreak","doc":"A soft line break.\n\nSpec: https://github.github.com/gfm/#soft-line-breaks","ref":"MDEx.SoftBreak.html"},{"type":"type","title":"MDEx.SoftBreak.t/0","doc":"","ref":"MDEx.SoftBreak.html#t:t/0"},{"type":"module","title":"MDEx.SpoileredText","doc":"Spoilered text.","ref":"MDEx.SpoileredText.html"},{"type":"type","title":"MDEx.SpoileredText.t/0","doc":"","ref":"MDEx.SpoileredText.html#t:t/0"},{"type":"module","title":"MDEx.Strikethrough","doc":"Strikethrough.\n\nSpec: https://github.github.com/gfm/#strikethrough-extension-","ref":"MDEx.Strikethrough.html"},{"type":"type","title":"MDEx.Strikethrough.t/0","doc":"","ref":"MDEx.Strikethrough.html#t:t/0"},{"type":"module","title":"MDEx.Strong","doc":"Strong emphasis.\n\nSpec: https://github.github.com/gfm/#emphasis-and-strong-emphasis","ref":"MDEx.Strong.html"},{"type":"type","title":"MDEx.Strong.t/0","doc":"","ref":"MDEx.Strong.html#t:t/0"},{"type":"module","title":"MDEx.Subscript","doc":"Subscript.","ref":"MDEx.Subscript.html"},{"type":"type","title":"MDEx.Subscript.t/0","doc":"","ref":"MDEx.Subscript.html#t:t/0"},{"type":"module","title":"MDEx.Superscript","doc":"Superscript.","ref":"MDEx.Superscript.html"},{"type":"type","title":"MDEx.Superscript.t/0","doc":"","ref":"MDEx.Superscript.html#t:t/0"},{"type":"module","title":"MDEx.Table","doc":"A table with rows and columns.\n\nSpec: https://github.github.com/gfm/#tables-extension-","ref":"MDEx.Table.html"},{"type":"type","title":"MDEx.Table.t/0","doc":"","ref":"MDEx.Table.html#t:t/0"},{"type":"module","title":"MDEx.TableCell","doc":"A table cell inside a table row.\n\nSee `MDEx.Table`","ref":"MDEx.TableCell.html"},{"type":"type","title":"MDEx.TableCell.t/0","doc":"","ref":"MDEx.TableCell.html#t:t/0"},{"type":"module","title":"MDEx.TableRow","doc":"A table row.\n\nSee `MDEx.Table`","ref":"MDEx.TableRow.html"},{"type":"type","title":"MDEx.TableRow.t/0","doc":"","ref":"MDEx.TableRow.html#t:t/0"},{"type":"module","title":"MDEx.TaskItem","doc":"A task item inside a list.\n\nSpec: https://github.github.com/gfm/#task-list-items-extension-","ref":"MDEx.TaskItem.html"},{"type":"type","title":"MDEx.TaskItem.t/0","doc":"","ref":"MDEx.TaskItem.html#t:t/0"},{"type":"module","title":"MDEx.Text","doc":"Literal text.\n\nSpec: https://github.github.com/gfm/#textual-content","ref":"MDEx.Text.html"},{"type":"type","title":"MDEx.Text.t/0","doc":"","ref":"MDEx.Text.html#t:t/0"},{"type":"module","title":"MDEx.ThematicBreak","doc":"A break between lines.\n\nSpec: https://github.github.com/gfm/#thematic-breaks","ref":"MDEx.ThematicBreak.html"},{"type":"type","title":"MDEx.ThematicBreak.t/0","doc":"","ref":"MDEx.ThematicBreak.html#t:t/0"},{"type":"module","title":"MDEx.Underline","doc":"Underline.","ref":"MDEx.Underline.html"},{"type":"type","title":"MDEx.Underline.t/0","doc":"","ref":"MDEx.Underline.html#t:t/0"},{"type":"module","title":"MDEx.WikiLink","doc":"A link in the form of a wiki link.","ref":"MDEx.WikiLink.html"},{"type":"type","title":"MDEx.WikiLink.t/0","doc":"","ref":"MDEx.WikiLink.html#t:t/0"},{"type":"exception","title":"MDEx.DecodeError","doc":"Failed to decode a Document.\n\nUsually this means that a `MDEx.Document` is invalid and cannot be decoded.","ref":"MDEx.DecodeError.html"},{"type":"function","title":"MDEx.DecodeError.message/1","doc":"","ref":"MDEx.DecodeError.html#message/1"},{"type":"type","title":"MDEx.DecodeError.t/0","doc":"","ref":"MDEx.DecodeError.html#t:t/0"},{"type":"exception","title":"MDEx.InvalidInputError","doc":"Given input is invalid.\n\nUsually this means that the input is not a string or a MDEx.Document struct.","ref":"MDEx.InvalidInputError.html"},{"type":"function","title":"MDEx.InvalidInputError.message/1","doc":"","ref":"MDEx.InvalidInputError.html#message/1"},{"type":"type","title":"MDEx.InvalidInputError.t/0","doc":"","ref":"MDEx.InvalidInputError.html#t:t/0"},{"type":"exception","title":"MDEx.InvalidSelector","doc":"Invalid Access key selector.","ref":"MDEx.InvalidSelector.html"},{"type":"function","title":"MDEx.InvalidSelector.message/1","doc":"","ref":"MDEx.InvalidSelector.html#message/1"},{"type":"type","title":"MDEx.InvalidSelector.t/0","doc":"","ref":"MDEx.InvalidSelector.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.4.2 (2025-03-25) - Changelog","doc":"","ref":"changelog.html#0-4-2-2025-03-25"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added target `riscv64gc-unknown-linux-gnu target`\n  * Added binaries for NIF version 2.16","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fixed glibc version mismatch on `x86_64-unknown-linux-gnu` target","ref":"changelog.html#fixes"},{"type":"extras","title":"Docs - Changelog","doc":"* Added section Pre-compilation listing all targets, how to compile the project,\n    and how to enable targets for legacy CPUs.\n  * Added example in `MDEx.Document` on how to bump Heading levels","ref":"changelog.html#docs"},{"type":"extras","title":"0.4.1 (2025-03-24) - Changelog","doc":"","ref":"changelog.html#0-4-1-2025-03-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added target `arm-unknown-linux-gnueabihf` used by Raspberry Pi","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.4.0 (2025-03-10) - Changelog","doc":"","ref":"changelog.html#0-4-0-2025-03-10"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added support for [GitHub](https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax#alerts)\n    and [GitLab](https://docs.gitlab.com/user/markdown/#alerts) alerts.\n  * Process alerts by default in Sigils.\n  * Added `:experimental_minimize_commonmark` render option.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Docs - Changelog","doc":"* Add nimble_publisher example by @PJUllrich","ref":"changelog.html#docs"},{"type":"extras","title":"Chores - Changelog","doc":"* Add sample Dockerfile for debugging","ref":"changelog.html#chores"},{"type":"extras","title":"0.3.3 (2025-02-03) - Changelog","doc":"","ref":"changelog.html#0-3-3-2025-02-03"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix `MDEx.Document.fetch/2` spec","ref":"changelog.html#fixes"},{"type":"extras","title":"0.3.2 (2025-01-11) - Changelog","doc":"","ref":"changelog.html#0-3-2-2025-01-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `MDEx.safe_html/2` utility function to sanitize and escape HTML content","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* HTML: encode `{` and `}` only inside ` ` tags to avoid disabling LiveView expressions","ref":"changelog.html#fixes"},{"type":"extras","title":"0.3.1 (2025-01-08) - Changelog","doc":"","ref":"changelog.html#0-3-1-2025-01-08"},{"type":"extras","title":"Enhancements - Changelog","doc":"* HTML: encode `{` and `}` as `&lbrace;` and `&rbrace;` to avoid LiveView syntax errors in HEEx templates","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.3.0 (2024-12-16) - Changelog","doc":"Be aware, this version introduces major breaking changes:\n- AST format has changed\n- Sigils `~m` and `~M` now returns `%MDEx.Document{}` instead of a Markdown string (use the `MD` modifier to have the old behavior)\n\nThese changes enables the implementation of protocols to improve the manipulation of the AST,\nsee the [MDEx.Document](https://hexdocs.pm/mdex/MDEx.Document.html) module and [examples](https://github.com/leandrocp/mdex/tree/main/examples) for more info.","ref":"changelog.html#0-3-0-2024-12-16"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* Changed the AST format from `{name, attributes, children}` to structs as `%MDEx.Heading{level: 1, nodes: [%MDEx.Text{literal: \"Hello\"}]}`\n  * Sigils `~m` and `~M` now returns `%MDEx.Document{}` instead of a Markdown string\n  * Removed `MDEx.attribute/2` in favor of pattern matching key/value pairs in node structs","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* New AST format based on structs\n  * Introduced modifiers `HTML`, `XML`, and `MD` for both sigils `~m` and `~M`\n  * Introduced `MDEx.traverse_and_update/3` with the `acc` argument\n  * Updated autumn to properly escape curly braces in HEEx template on LiveView 1.0\n  * Updated comrak to v0.31\n      - New node `MDEx.Subscript`\n      - New attr `is_task_item` in list nodes\n      - New option `render.figure_with_caption`\n      - New option `render.tasklist_classes`\n      - New option `render.ol_width`","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.2.0 (2024-10-09) - Changelog","doc":"","ref":"changelog.html#0-2-0-2024-10-09"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* `to_html/1` and `to_html/2` now returns `{:ok, String.t()}` or `{:error, %MDEx.DecodeError{}}` instead of just `String.t()`.\n    The reason is because now they may accept an AST as input which may cause decoding errors.\n    Replace with `to_html!/1` and `to_html!/2` to have the same behavior as before.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix misspelling of `thematic` causing render errors - [#73](https://github.com/leandrocp/mdex/pull/73) by @jonklein","ref":"changelog.html#fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added `to_commonmark/1` and `to_commonmark/2` to convert an AST to CommonMark - [#70](https://github.com/leandrocp/mdex/pull/70) by @jonklein\n  * Added `~M` sigil (no interpolation) with `AST` and `MD` modifiers (defaults to HTML without the modifier)\n  * Added `~m` sigil (supports interpolation and escaping) with `AST` and `MD` modifiers (defaults to HTML without the modifier)\n  * Added `parse_document/1` and `parse_document/2` to parse Markdown to AST\n  * Added low-level functions `traverse_and_update/2` and `attribute/2` to manipulate AST\n  * Added `to_html!/1` and `to_html!/2`, the raising version of `to_html/1` and `to_html/2` (similar to previous `to_html/1` and `to_html/2`)\n  * Changed `to_html/1` and `to_html/2` to accept AST as input\n  * Added examples directory to show how to use the new APIs","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.18 (2024-07-13) - Changelog","doc":"","ref":"changelog.html#0-1-18-2024-07-13"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Bump comrak from [0.24.1 to 0.26.0](https://github.com/kivikakk/comrak/blob/9f4d391abe2857031f993c4cdddf1ebba7cdbc7d/changelog.txt#L1-L60)\n  * Add new `extension` options: underline, spoiler, greentext\n  * Add new `render` options: experimental_inline_sourcepos, escaped_char_spans, ignore_setext, ignore_empty_links, gfm_quirks, prefer_fenced","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.17 (2024-06-19) - Changelog","doc":"","ref":"changelog.html#0-1-17-2024-06-19"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Relax minimum required Elixir version to 1.13\n  * Bump comrak to 0.24.1\n  * Bump ammonia to 4.0\n  * Add new `extension` options: multiline_block_quotes, math_dollars, math_code, shortcodes, wikilinks_title_after_pipe, wikilinks_title_before_pipe\n  * Add new `render` option: escaped_char_spans\n  * Add new option `features.syntax_highlight_inline_style` to control whether to embed inline styles or not. Default is `true`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Changed - Changelog","doc":"* Build binaries on MacOS 12","ref":"changelog.html#changed"},{"type":"extras","title":"0.1.16 (2024-04-29) - Changelog","doc":"","ref":"changelog.html#0-1-16-2024-04-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added language `objc` to syntax highlighter.","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.15 (2024-04-16) - Changelog","doc":"","ref":"changelog.html#0-1-15-2024-04-16"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update rustler to `~> 0.32`\n  * Update rustler_precompiled `~> 0.7`\n  * Added legacy targets","ref":"changelog.html#enhancements"},{"type":"extras","title":"Backwards incompatible changes - Changelog","doc":"* Minimum required Elixir version is now 1.14\n  * Removed target `arm-unknown-linux-gnueabihf`\n  * Removed target `riscv64gc-unknown-linux-gnu`","ref":"changelog.html#backwards-incompatible-changes"},{"type":"extras","title":"0.1.14 (2024-04-11) - Changelog","doc":"","ref":"changelog.html#0-1-14-2024-04-11"},{"type":"extras","title":"Backwards incompatible changes - Changelog","doc":"* [Syntax Highlight] Renamed parent ` ` class from `autumn-highlight` to `autumn-hl`\n  * [Syntax Highlight] Added prefix `ahl-` to each scope class","ref":"changelog.html#backwards-incompatible-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update autumn to 0.2.2 (#33)\n  * Update comrak to 0.20.0 (#27) - @supernintendo","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.13 (2023-11-20) - Changelog","doc":"","ref":"changelog.html#0-1-13-2023-11-20"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update autumn themes to add base16-tomorrow and base16-tomorrow-night - @paradox460","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.12 (2023-11-06) - Changelog","doc":"","ref":"changelog.html#0-1-12-2023-11-06"},{"type":"extras","title":"Fixes - Changelog","doc":"* Comrak docs links","ref":"changelog.html#fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add languages: jsx, tsx, vim\n  * Bump injket v0.10.2","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.11 (2023-10-25) - Changelog","doc":"","ref":"changelog.html#0-1-11-2023-10-25"},{"type":"extras","title":"Fixes - Changelog","doc":"* Syntax highlighting - remove newlines to avoid formatting incorrectly","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.10 (2023-10-24) - Changelog","doc":"","ref":"changelog.html#0-1-10-2023-10-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add translate=\"no\" attr in ` ` tag","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix Javascript syntax highlight\n  * Fix Typescript syntax highlight","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.9 (2023-09-29) - Changelog","doc":"","ref":"changelog.html#0-1-9-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add logo\n  * Add icon","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.8 (2023-09-29) - Changelog","doc":"","ref":"changelog.html#0-1-8-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fallback to plain text on invalid language\n  * Syntax highlight injections\n  * Add samples","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.7 (2023-09-27) - Changelog","doc":"","ref":"changelog.html#0-1-7-2023-09-27"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Syntax highlight code using tree-sitter and helix editor themes. Use https://github.com/leandrocp/autumn/tree/main/native/inkjet_nif under the hood.","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.6 (2023-09-14) - Changelog","doc":"","ref":"changelog.html#0-1-6-2023-09-14"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Load extra themes and syntaxes with https://crates.io/crates/two-face","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.5 (2023-09-12) - Changelog","doc":"","ref":"changelog.html#0-1-5-2023-09-12"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Sanitize output with https://crates.io/crates/ammonia\n  * Syntax Highlight with https://crates.io/crates/syntect","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.4 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-4-2023-09-11"},{"type":"extras","title":"Fixes - Changelog","doc":"* Compile on Ubuntu 20 to fix libc version mismatch","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.3 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-3-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* NIF version 2.15","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.2 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-2-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Guard markdown arg","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* specs","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.1 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-1-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update Rust to edition 2021\n  * Add `@spec` to public functions","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.0 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-0-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* `MDEx.to_html/1` to convert Markdown to HTML using default options.\n  * `MDEx.to_html/2` to convert Markdown to HTML using custom options.","ref":"changelog.html#enhancements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}